@@ -29,6 +29,12 @@ const char *gs_file_get_path_cached (GFile *file);
 
 const char *gs_file_get_basename_cached (GFile *file);
 
+gboolean gs_file_enumerator_iterate (GFileEnumerator  *direnum,
+                                     GFileInfo       **out_info,
+                                     GFile           **out_child,
+                                     GCancellable     *cancellable,
+                                     GError          **error);
+
 GInputStream *gs_file_read_noatime (GFile         *file,
                                     GCancellable  *cancellable,
                                     GError       **error);
@@ -36,9 +42,11 @@ GMappedFile *gs_file_map_noatime (GFile         *file,
                                   GCancellable  *cancellable,
                                   GError       **error);
 
+#if GLIB_CHECK_VERSION(2,34,0)
 GBytes *gs_file_map_readonly (GFile         *file,
                               GCancellable  *cancellable,
                               GError       **error);
+#endif
 
 gboolean gs_file_sync_data (GFile          *file,
                             GCancellable   *cancellable,
