@@ -24,30 +24,32 @@
 
 #include <gio/gio.h>
 
+#include <errno.h>
 #include <string.h>
 
 #include "ot-main.h"
 #include "ot-builtins.h"
 
-static OstreeBuiltin builtins[] = {
+static OstreeCommand commands[] = {
+  { "admin", ostree_builtin_admin, OSTREE_BUILTIN_FLAG_NO_REPO },
   { "cat", ostree_builtin_cat, 0 },
+  { "commit", ostree_builtin_commit, 0 },
   { "config", ostree_builtin_config, 0 },
   { "checkout", ostree_builtin_checkout, 0 },
   { "checksum", ostree_builtin_checksum, OSTREE_BUILTIN_FLAG_NO_REPO },
   { "diff", ostree_builtin_diff, 0 },
+  { "fsck", ostree_builtin_fsck, 0 },
   { "init", ostree_builtin_init, 0 },
-  { "commit", ostree_builtin_commit, 0 },
-  { "pull-local", ostree_builtin_pull_local, 0 },
   { "log", ostree_builtin_log, 0 },
   { "ls", ostree_builtin_ls, 0 },
+  { "refs", ostree_builtin_refs, 0 },
   { "prune", ostree_builtin_prune, 0 },
-  { "fsck", ostree_builtin_fsck, 0 },
-  { "pack", ostree_builtin_pack, 0 },
+  { "pull", ostree_builtin_pull, 0 },
+  { "pull-local", ostree_builtin_pull_local, 0 },
   { "remote", ostree_builtin_remote, 0 },
   { "rev-parse", ostree_builtin_rev_parse, 0 },
-  { "remote", ostree_builtin_remote, 0 },
   { "show", ostree_builtin_show, 0 },
-  { "unpack", ostree_builtin_unpack, 0 },
+  { "trivial-httpd", ostree_builtin_trivial_httpd, OSTREE_BUILTIN_FLAG_NO_REPO },
   { "write-refs", ostree_builtin_write_refs, 0 },
   { NULL }
 };
@@ -56,5 +58,18 @@ int
 main (int    argc,
       char **argv)
 {
-  return ostree_main (argc, argv, builtins);
+  GError *error = NULL;
+  int ret;
+
+  ret = ostree_run (argc, argv, commands, &error);
+  if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED))
+    ostree_usage (argv, commands, TRUE);
+
+  if (error != NULL)
+    {
+      g_printerr ("%s\n", error->message);
+      g_error_free (error);
+    }
+
+  return ret;
 }
