@@ -30,7 +30,7 @@
 #include <glib/gi18n.h>
 
 static gboolean opt_user_mode;
-static gboolean opt_no_triggers;
+static gboolean opt_allow_noent;
 static char *opt_subpath;
 static gboolean opt_union;
 static gboolean opt_from_stdin;
@@ -40,7 +40,7 @@ static GOptionEntry options[] = {
   { "user-mode", 'U', 0, G_OPTION_ARG_NONE, &opt_user_mode, "Do not change file ownership or initialize extended attributes", NULL },
   { "subpath", 0, 0, G_OPTION_ARG_STRING, &opt_subpath, "Checkout sub-directory PATH", "PATH" },
   { "union", 0, 0, G_OPTION_ARG_NONE, &opt_union, "Keep existing directories, overwrite existing files", NULL },
-  { "no-triggers", 0, 0, G_OPTION_ARG_NONE, &opt_no_triggers, "Don't run triggers", NULL },
+  { "allow-noent", 0, 0, G_OPTION_ARG_NONE, &opt_allow_noent, "Do nothing if specified path does not exist", NULL },
   { "from-stdin", 0, 0, G_OPTION_ARG_NONE, &opt_from_stdin, "Process many checkouts from standard input", NULL },
   { "from-file", 0, 0, G_OPTION_ARG_STRING, &opt_from_file, "Process many checkouts from input file", NULL },
   { NULL }
@@ -89,9 +89,10 @@ process_one_checkout (OstreeRepo           *repo,
 {
   gboolean ret = FALSE;
   ProcessOneCheckoutData data;
-  ot_lobj OstreeRepoFile *root = NULL;
-  ot_lobj OstreeRepoFile *subtree = NULL;
-  ot_lobj GFileInfo *file_info = NULL;
+  GError *tmp_error = NULL;
+  gs_unref_object OstreeRepoFile *root = NULL;
+  gs_unref_object OstreeRepoFile *subtree = NULL;
+  gs_unref_object GFileInfo *file_info = NULL;
 
   memset (&data, 0, sizeof (data));
   
@@ -106,9 +107,21 @@ process_one_checkout (OstreeRepo           *repo,
 
   file_info = g_file_query_info ((GFile*)subtree, OSTREE_GIO_FAST_QUERYINFO,
                                  G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-                                 cancellable, error);
+                                 cancellable, &tmp_error);
   if (!file_info)
-    goto out;
+    {
+      if (opt_allow_noent
+          && g_error_matches (tmp_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
+        {
+          g_clear_error (&tmp_error);
+          ret = TRUE;
+        }
+      else
+        {
+          g_propagate_error (error, tmp_error);
+        }
+      goto out;
+    }
 
   data.loop = g_main_loop_new (NULL, TRUE);
   data.error = error;
@@ -139,11 +152,11 @@ process_many_checkouts (OstreeRepo         *repo,
   gboolean ret = FALSE;
   gsize len;
   GError *temp_error = NULL;
-  ot_lobj GInputStream *instream = NULL;
-  ot_lobj GDataInputStream *datastream = NULL;
-  ot_lfree char *revision = NULL;
-  ot_lfree char *subpath = NULL;
-  ot_lfree char *resolved_commit = NULL;
+  gs_unref_object GInputStream *instream = NULL;
+  gs_unref_object GDataInputStream *datastream = NULL;
+  gs_free char *revision = NULL;
+  gs_free char *subpath = NULL;
+  gs_free char *resolved_commit = NULL;
 
   if (opt_from_stdin)
     {
@@ -151,7 +164,7 @@ process_many_checkouts (OstreeRepo         *repo,
     }
   else
     {
-      ot_lobj GFile *f = g_file_new_for_path (opt_from_file);
+      gs_unref_object GFile *f = g_file_new_for_path (opt_from_file);
 
       instream = (GInputStream*)g_file_read (f, cancellable, error);
       if (!instream)
@@ -211,14 +224,14 @@ ostree_builtin_checkout (int argc, char **argv, GFile *repo_path, GError **error
   gboolean ret = FALSE;
   const char *commit;
   const char *destination;
-  ot_lobj OstreeRepo *repo = NULL;
-  ot_lfree char *existing_commit = NULL;
-  ot_lfree char *resolved_commit = NULL;
-  ot_lfree char *tmp_destination = NULL;
-  ot_lobj GFileInfo *symlink_file_info = NULL;
-  ot_lobj GFile *checkout_target = NULL;
-  ot_lobj GFile *checkout_target_tmp = NULL;
-  ot_lobj GFile *symlink_target = NULL;
+  gs_unref_object OstreeRepo *repo = NULL;
+  gs_free char *existing_commit = NULL;
+  gs_free char *resolved_commit = NULL;
+  gs_free char *tmp_destination = NULL;
+  gs_unref_object GFileInfo *symlink_file_info = NULL;
+  gs_unref_object GFile *checkout_target = NULL;
+  gs_unref_object GFile *checkout_target_tmp = NULL;
+  gs_unref_object GFile *symlink_target = NULL;
 
   context = g_option_context_new ("COMMIT DESTINATION - Check out a commit into a filesystem tree");
   g_option_context_add_main_entries (context, options, NULL);
@@ -247,12 +260,6 @@ ostree_builtin_checkout (int argc, char **argv, GFile *repo_path, GError **error
 
       if (!process_many_checkouts (repo, checkout_target, cancellable, error))
         goto out;
-      
-      if (!opt_no_triggers)
-        {
-          if (!ostree_run_triggers_in_root (checkout_target, cancellable, error))
-            goto out;
-        }
     }
   else
     {
@@ -271,13 +278,6 @@ ostree_builtin_checkout (int argc, char **argv, GFile *repo_path, GError **error
                                  checkout_target_tmp ? checkout_target_tmp : checkout_target,
                                  cancellable, error))
         goto out;
-
-      if (!opt_no_triggers)
-        {
-          if (!ostree_run_triggers_in_root (checkout_target_tmp ? checkout_target_tmp : checkout_target,
-                                            cancellable, error))
-            goto out;
-        }
     }
 
   ret = TRUE;
