@@ -28,7 +28,10 @@
 #include <unistd.h>
 #include <stdlib.h>
 
+static char *opt_remote;
+
 static GOptionEntry options[] = {
+  { "remote", 0, 0, G_OPTION_ARG_STRING, &opt_remote, "Add REMOTE to refspec", "REMOTE" },
   { NULL }
 };
 
@@ -43,6 +46,12 @@ typedef struct {
   GSConsole *console;
 } OtLocalCloneData;
 
+static gboolean
+termination_condition (OtLocalCloneData  *self)
+{
+  return g_atomic_int_get (&self->n_objects_checked) == self->n_objects_to_check;
+}
+
 static gboolean
 import_one_object (OtLocalCloneData *data,
                    const char   *checksum,
@@ -51,16 +60,16 @@ import_one_object (OtLocalCloneData *data,
                    GError        **error)
 {
   gboolean ret = FALSE;
-  ot_lobj GFile *content_path = NULL;
-  ot_lobj GFileInfo *archive_info = NULL;
+  gs_unref_object GFile *content_path = NULL;
+  gs_unref_object GFileInfo *archive_info = NULL;
 
   if (objtype == OSTREE_OBJECT_TYPE_FILE)
     {
       guint64 length;
-      ot_lobj GInputStream *file_object = NULL;
-      ot_lobj GInputStream *input = NULL;
-      ot_lobj GFileInfo *file_info = NULL;
-      ot_lvariant GVariant *xattrs = NULL;
+      gs_unref_object GInputStream *file_object = NULL;
+      gs_unref_object GInputStream *input = NULL;
+      gs_unref_object GFileInfo *file_info = NULL;
+      gs_unref_variant GVariant *xattrs = NULL;
 
       if (!ostree_repo_load_file (data->src_repo, checksum,
                                   &input, &file_info, &xattrs,
@@ -79,7 +88,7 @@ import_one_object (OtLocalCloneData *data,
     }
   else
     {
-      ot_lvariant GVariant *metadata = NULL;
+      gs_unref_variant GVariant *metadata = NULL;
 
       if (!ostree_repo_load_variant (data->src_repo, objtype, checksum, &metadata,
                                      error))
@@ -102,7 +111,7 @@ import_one_object_thread (gpointer   object,
                           gpointer   user_data)
 {
   OtLocalCloneData *data = user_data;
-  ot_lvariant GVariant *serialized_key = object;
+  gs_unref_variant GVariant *serialized_key = object;
   GError *local_error = NULL;
   GError **error = &local_error;
   const char *checksum;
@@ -123,8 +132,9 @@ import_one_object_thread (gpointer   object,
     }
   
  out:
-  if (g_atomic_int_add (&data->n_objects_checked, 1) == data->n_objects_to_check - 1)
-    g_main_loop_quit (data->loop);
+  g_atomic_int_add (&data->n_objects_checked, 1);
+  if (termination_condition (data))
+    g_main_context_wakeup (NULL);
   if (local_error != NULL)
     {
       g_printerr ("%s\n", local_error->message);
@@ -160,16 +170,16 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
   int i;
   GHashTableIter hash_iter;
   gpointer key, value;
-  ot_lhash GHashTable *objects = NULL;
-  ot_lobj GFile *src_f = NULL;
-  ot_lobj GFile *src_repo_dir = NULL;
-  ot_lobj GFile *dest_repo_dir = NULL;
-  ot_lobj GFile *src_dir = NULL;
-  ot_lobj GFile *dest_dir = NULL;
-  ot_lhash GHashTable *refs_to_clone = NULL;
-  ot_lhash GHashTable *commits_to_clone = NULL;
-  ot_lhash GHashTable *source_objects = NULL;
-  ot_lhash GHashTable *objects_to_copy = NULL;
+  gs_unref_hashtable GHashTable *objects = NULL;
+  gs_unref_object GFile *src_f = NULL;
+  gs_unref_object GFile *src_repo_dir = NULL;
+  gs_unref_object GFile *dest_repo_dir = NULL;
+  gs_unref_object GFile *src_dir = NULL;
+  gs_unref_object GFile *dest_dir = NULL;
+  gs_unref_hashtable GHashTable *refs_to_clone = NULL;
+  gs_unref_hashtable GHashTable *commits_to_clone = NULL;
+  gs_unref_hashtable GHashTable *source_objects = NULL;
+  gs_unref_hashtable GHashTable *objects_to_copy = NULL;
   OtLocalCloneData datav;
   OtLocalCloneData *data = &datav;
 
@@ -203,14 +213,14 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
     goto out;
 
   data->threadpool = ot_thread_pool_new_nproc (import_one_object_thread, data);
-  data->loop = g_main_loop_new (NULL, TRUE);
 
   src_repo_dir = g_object_ref (ostree_repo_get_path (data->src_repo));
   dest_repo_dir = g_object_ref (ostree_repo_get_path (data->dest_repo));
 
   if (argc == 2)
     {
-      if (!ostree_repo_list_all_refs (data->src_repo, &refs_to_clone, cancellable, error))
+      if (!ostree_repo_list_refs (data->src_repo, NULL, &refs_to_clone,
+                                  cancellable, error))
         goto out;
     }
   else
@@ -268,11 +278,11 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
   if (!ostree_repo_prepare_transaction (data->dest_repo, FALSE, cancellable, error))
     goto out;
 
+  data->n_objects_to_check = g_hash_table_size (source_objects);
   g_hash_table_iter_init (&hash_iter, source_objects);
   while (g_hash_table_iter_next (&hash_iter, &key, &value))
     {
       GVariant *serialized_key = key;
-      data->n_objects_to_check++;
       g_thread_pool_push (data->threadpool, g_variant_ref (serialized_key), NULL);
     }
 
@@ -286,7 +296,8 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
       g_timeout_add_seconds (1, idle_print_status, data);
       idle_print_status (data);
 
-      g_main_loop_run (data->loop);
+      while (!termination_condition (data))
+        g_main_context_iteration (NULL, TRUE);
 
       idle_print_status (data);
       if (data->console)
@@ -303,15 +314,15 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
     {
       const char *name = key;
       const char *checksum = value;
-
-      if (!ostree_repo_write_ref (data->dest_repo, NULL, name, checksum, error))
+        
+      if (!ostree_repo_write_ref (data->dest_repo, opt_remote, name, checksum,
+                                  error))
         goto out;
     }
 
   ret = TRUE;
  out:
   g_clear_pointer (&data->threadpool, (GDestroyNotify) g_thread_pool_free);
-  g_clear_pointer (&data->loop, (GDestroyNotify) g_main_loop_unref);
   if (data->src_repo)
     g_object_unref (data->src_repo);
   if (data->dest_repo)
