@@ -38,10 +38,10 @@ ostree_builtin_rev_parse (int argc, char **argv, GFile *repo_path, GError **erro
   gboolean ret = FALSE;
   const char *rev = "master";
   int i;
-  ot_lobj OstreeRepo *repo = NULL;
-  ot_lfree char *resolved_rev = NULL;
-  ot_lvariant GVariant *variant = NULL;
-  ot_lfree char *formatted_variant = NULL;
+  gs_unref_object OstreeRepo *repo = NULL;
+  gs_free char *resolved_rev = NULL;
+  gs_unref_variant GVariant *variant = NULL;
+  gs_free char *formatted_variant = NULL;
 
   context = g_option_context_new ("REV - Output the target of a rev");
   g_option_context_add_main_entries (context, options, NULL);
